@@ -17,14 +17,12 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 - 2012 Red Hat, Inc.
+ * Copyright 2008 - 2014 Red Hat, Inc.
  */
 
 #ifndef __PAGE_BRIDGE_PORT_H__
 #define __PAGE_BRIDGE_PORT_H__
 
-#include <nm-connection.h>
-
 #include <glib.h>
 #include <glib-object.h>
 
@@ -51,7 +49,6 @@ CEPage *ce_page_bridge_port_new (NMConnectionEditor *editor,
                                  NMConnection *connection,
                                  GtkWindow *parent,
                                  NMClient *client,
-                                 NMRemoteSettings *settings,
                                  const char **out_secrets_setting_name,
                                  GError **error);
 
