@@ -204,11 +204,8 @@ add_slave (CEPageMaster *master, NewConnectionResultFunc result_func)
 }
 
 static void
-finish_setup (CEPageBridge *self, gpointer unused, GError *error, gpointer user_data)
+finish_setup (CEPageBridge *self, gpointer user_data)
 {
-	if (error)
-		return;
-
 	populate_ui (self);
 }
 
@@ -246,7 +243,7 @@ ce_page_bridge_new (NMConnectionEditor *editor,
 		nm_connection_add_setting (connection, NM_SETTING (priv->setting));
 	}
 
-	g_signal_connect (self, "initialized", G_CALLBACK (finish_setup), NULL);
+	g_signal_connect (self, CE_PAGE_INITIALIZED, G_CALLBACK (finish_setup), NULL);
 
 	return CE_PAGE (self);
 }
